/* Copyright (C) 1996 Free Software Foundation, Inc.
This file is part of the GNU C Library.

The GNU C Library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public License as
published by the Free Software Foundation; either version 2 of the
License, or (at your option) any later version.

The GNU C Library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with the GNU C Library; see the file COPYING.LIB.  If
not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA.  */

#include "ansidecl.h"
#include <stddef.h>

CONST char *CONST _sys_errlist[] =
{
    "Success",
    "Operation not permitted",          /* 1 = EPERM */
    "No such file or directory",        /* 2 = ENOENT */
    "No such process",                  /* 3 = ESRCH */
    "Interrupted system call",          /* 4 = EINTR */
    "Input/output error",               /* 5 = EIO */
    "No such device or address",        /* 6 = ENXIO */
    "Argument list too long",           /* 7 = E2BIG */
    "Exec format error",                /* 8 = ENOEXEC */
    "Bad file descriptor",              /* 9 = EBADF */
    "No child processes",               /* 10 = ECHILD */
    "Try again",                        /* 11 = EAGAIN */
    "Out of memory",                    /* 12 = ENOMEM */
    "Permission denied",                /* 13 = EACCES */
    "Bad address",                      /* 14 = EFAULT */
    "Block device required",            /* 15 = ENOTBLK */
    "Device busy",                      /* 16 = EBUSY */
    "File exists",                      /* 17 = EEXIST */
    "Invalid cross-device link",        /* 18 = EXDEV */
    "Operation not supported by device",/* 19 = ENODEV */
    "Not a directory",                  /* 20 = ENOTDIR */
    "Is a directory",                   /* 21 = EISDIR */
    "Invalid argument",                 /* 22 = EINVAL */
    "Too many open files in system",    /* 23 = ENFILE */
    "Too many open files",              /* 24 = EMFILE */
    "Not a typewriter",                 /* 25 = ENOTTY */
    "Text file busy",                   /* 26 = ETXTBSY */
    "File too large",                   /* 27 = EFBIG */
    "No space left on device",          /* 28 = ENOSPC */
    "Illegal seek",                     /* 29 = ESPIPE */
    "Read-only file system",            /* 30 = EROFS */
    "Too many links",                   /* 31 = EMLINK */
    "Broken pipe",                      /* 32 = EPIPE */
    "Numerical argument out of domain", /* 33 = EDOM */
    "Numerical result out of range",    /* 34 = ERANGE */
    "No message of desired type",       /* 35 = ENOMSG */
    "Identifier removed",               /* 36 = EIDRM */
    "Channel number out of range",      /* 37 = ECHRNG */
    "Level 2 not synchronized",         /* 38 = EL2NSYNC */
    "Level 3 halted",                   /* 39 = EL3HLT */
    "Level 3 reset",                    /* 40 = EL3RST */
    "Link number out of range",         /* 41 = ELNRNG */
    "Protocol driver not attached",     /* 42 = EUNATCH */
    "No CSI structure available",       /* 43 = ENOCSI */
    "Level 2 halted",                   /* 44 = EL2HLT */
    "Resource deadlock avoided",        /* 45 = EDEADLK */ 
    "No record locks available",        /* 46 = ENOLCK */
    "Reserved error 47",
    "Reserved error 48",
    "Reserved error 49",
    "Invalid exchange",                 /* 50 = EBADE */
    "Invalid request descriptor",       /* 51 = EBADR */
    "Exchange full",                    /* 52 = EXFULL */
    "No anode",                         /* 53 = ENOANO */
    "Invalid request code",             /* 54 = EBADRQC */
    "Invalid slot",                     /* 55 = EBADSLT */
    "File locking deadlock error",      /* 56 = EDEADLOCK */
    "Reserved error 57",
    "Reserved error 58",
    "Bad font file format",             /* 59 = EBFONT */
    "Device not a stream",              /* 60 = ENOSTR */
    "No data available",                /* 61 = ENODATA */
    "Timer expired",                    /* 62 = ETIME */
    "Out of streams resources",         /* 63 = ENOSR */
    "Machine is not on the network",    /* 64 = ENONET */
    "Package not installed",            /* 65 = ENOPKG */
    "Object is remote",                 /* 66 = EREMOTE */
    "Link has been severed",            /* 67 = ENOLINK */
    "Advertise error",                  /* 68 = EADV */
    "Srmount error",                    /* 69 = ESRMNT */
    "Communication error on send",      /* 70 = ECOMM */
    "Protocol error",                   /* 71 = EPROTO */
    "Reserved error 72",
    "RFS specific error",               /* 73 = EDOTDOT */
    "Multihop attempted",               /* 74 = EMULTIHOP */
    "Reserved error 75",
    "Reserved error 76",
    "Not a data message",               /* 77 = EBADMSG */
    "File name too long",               /* 78 = ENAMETOOLONG */
    "Value too large for defined data type",/* 79 = EOVERFLOW */
    "Name not unique on network",       /* 80 = ENOTUNIQ */
    "File descriptor in bad state"      /* 81 = EBADFD */
    "Remote address changed",           /* 82 = EREMCHG */
    "Can not access a needed shared library", /* 83 = ELIBACC */
    "Accessing a corrupted shared library", /* 84 = ELIBBAD */
    ".lib section in a.out corrupted",  /* 85 = ELIBSCN */
    "Too many shared libraries",        /* 86 = ELIBMAX */
    "Cannot exec a shared library directly", /* 87 = ELIBEXEC */
    "Illegal byte sequence",            /* 88 = EILSEQ */
    "Function not implemented",         /* 89 = ENOSYS */
    "Too many links",                   /* 90 = ELOOP */
    "Interrupted system call",          /* 91 = ERESTART */
    "Streams pipe error",               /* 92 = ESTRPIPE */
    "Streams pipe error",               /* 93 = ENOTEMPTY */
    "Too many users",                   /* 94 = EUSERS */
    "Socket operation on non-socket",   /* 95 = ENOTSOCK */
    "Destination address required",     /* 96 = EDESTADDRREQ */
    "Message too long",                 /* 97 = EMSGSIZE */
    "Protocol wrong type for socket",   /* 98 = EPROTOTYPE */
    "Protocol not available",           /* 99 = ENOPROTOOPT */
    "Reserved error 100",
    "Reserved error 101",
    "Reserved error 102",
    "Reserved error 103",
    "Reserved error 104",
    "Reserved error 105",
    "Reserved error 106",
    "Reserved error 107",
    "Reserved error 108",
    "Reserved error 109",
    "Reserved error 110",
    "Reserved error 111",
    "Reserved error 112",
    "Reserved error 113",
    "Reserved error 114",
    "Reserved error 115",
    "Reserved error 116",
    "Reserved error 117",
    "Reserved error 118",
    "Reserved error 119",
    "Protocol not supported",           /* 120 = EPROTONOSUPPORT */
    "Socket type not supported",        /* 121 = ESOCKTNOSUPPORT */
    "Operation not supported",          /* 122 = EOPNOTSUPP */
    "Protocol family not supported",    /* 123 = EPFNOSUPPORT */
    "Address family not supported by protocol", /* 124 = EAFNOSUPPORT */
    "Address already in use",           /* 125 = EADDRINUSE */
    "Cannot assign requested address"   /* 126 = EADDRNOTAVAIL */
    "Network is down",                  /* 127 = ENETDOWN */
    "Network is unreachable",           /* 128 = ENETUNREACH */
    "Network dropped connection on reset", /* 129 = ENETRESET */
    "Software caused connection abort", /* 130 = ECONNABORTED */
    "Connection reset by peer",         /* 131 = ECONNRESET */
    "No buffer space available",        /* 132 = ENOBUFS */
    "Socket is already connected",      /* 133 = EISCONN */
    "Socket is not connected",          /* 134 = ENOTCONN */
    "Structure needs cleaning",         /* 135 = EUCLEAN */
    "Reserved error 136",
    "Not a XENIX named type file",      /* 137 = ENOTNAM */
    "No XENIX semaphores available",    /* 138 = ENAVAIL */
    "Is a named type file",             /* 139 = EISNAM */
    "Remote I/O error",                 /* 140 = EREMOTEIO */
    "Reserved error 141",               /* 141 = EINIT */
    "Error 142",                        /* 142 = EREMDEV */
    "Can't send after socket shutdown", /* 143 = ESHUTDOWN */
    "Too many references: cannot splice", /* 144 = ETOOMANYREFS */
    "Connection timed out",             /* 145 = ETIMEDOUT */
    "Connection refused",               /* 146 = ECONNREFUSED */
    "Host is down",                     /* 147 = EHOSTDOWN */
    "No route to host",                 /* 148 = EHOSTUNREACH */
    "Operation already in progress",    /* 149 = EALREADY */
    "Operation now in progress",        /* 150 = EINPROGRESS */
    "Stale NFS file handle",            /* 151 = ESTALE */
    "Reserved error 152",
    "Reserved error 153",
    "Reserved error 154",
    "Reserved error 155",
    "Reserved error 156",
    "Reserved error 157",
    "AIO operation canceled",           /* 158 = ECANCELED */

    /*
     * Almost 1000 unused entryies in this table would make a huge
     * blowup in size, so I leave 'em unused for now.  We need something
     * more intelligent than just a bloated array to handle such big numbers.
     */
#if 0
    "Quota exceeded",                   /* 1133 = EDQUOT */
    "???",                              /* 1134 = ENFSREMOTE */
#endif
};

CONST int _sys_nerr = sizeof (_sys_errlist) / sizeof (_sys_errlist[0]);

weak_alias (_sys_errlist, sys_errlist)
weak_alias (_sys_nerr, sys_nerr)
